
/* ------------------- Question Bank Interface ----------------- */

/* This is the code for managing the question bank of the Mathematics
 * Olympiad. Access to the question bank is restricted. Authorised
 * users must enter their password, which is stored as is (no
 * encryption) in the database. Once the user has cleared the password
 * check, she can Add new questions in a particular category and
 * Edit/Delete questions submitted earlier. Note that only those
 * questions that have been submitted by this user can be modified.
*/

import java.awt.*;
import java.applet.*;
import java.io.*;
import java.sql.*;

/* ---------- Include this in the HTML file ------------ */
/*
	<applet code="QBInterface" width=130 height=200>
	 Please use a Java compatible browser like Netscape.
	</applet>
*/
/*--------------------------------------------------------*/


//////////////////////////
// The main (applet) class
//////////////////////////

public class QBInterface extends Applet
{
	boolean worked = false;     // Flag to remember if something has
								// been done
	mainQBDialogFrame inputFrame;

	// User ID:
	TextField login;
	TextField password;

	// Declare JDBC variables...
	
	// (1) The driver to load
  	static final String driver = "oracle.jdbc.driver.OracleDriver";

  	// (2) The connect string 
  	static final String connect_string = 
                  "jdbc:oracle:thin:satyam/satyam@everest:1521:GEN";

	// (3)The connection to the database
	Connection conn;


	public void init()
	{
		add ( new Label ( "Question Bank", Label.RIGHT ) );

		// User input capture...

		login = new TextField ( "", 10 );
		login.setEditable ( true );

		password = new TextField ( "", 10 );
		password.setEditable ( true );
		password.setEchoChar ( '+' );

		Button ok = new Button ( "OK" );

		add ( new Label ( "Login Name : ", Label.RIGHT ) );
		add ( login );
		add ( new Label ( "Password : ", Label.RIGHT ) );
		add ( password );

		add ( ok );
	}

	public void stop() { if ( worked ) inputFrame.setVisible ( false ); }

	public boolean action ( Event evtObj, Object arg )
	{
		myError error;
		if ( evtObj.target instanceof Button )
		{
			if ( arg.equals ( "OK" ) )
			{
				// First validate the password...
				try
				{
					// Call initialiser functions	
					Class.forName (driver);

					// Connect to the database
					conn = DriverManager.getConnection (connect_string);
	
					// The query statement...
					PreparedStatement validate_stmt = conn.prepareStatement ("Select password from professor where prof_id=?");
					validate_stmt.setString(1,login.getText());
					ResultSet pass=validate_stmt.executeQuery();

					// If the login exists and the password for that
					// login matches the one inputted, all is well...
					if(pass.next() && (password.getText()).equals(pass.getString(1)))
					{
						worked = true;

						// Set up the input frame...
						inputFrame = new mainQBDialogFrame ( "MO Question Bank", login.getText() );
						inputFrame.show();
						inputFrame.setSize ( 500, 350 );
					}
					else	// Bad password :-(
					{
						// Display error msg. ...
						error = new myError ( "Login Error", 50, 50 );
						error.show();
						error.resize ( 200, 100 );
					}
				}
				catch(Exception e)
				{
					// Oops! DBase error...
					myError an_error;
					an_error = new myError ( e.getMessage(), 80, 80 );
					an_error.show();
					an_error.resize ( 200, 100 );
				}
			return true;
			}
		}
		return false;
	}
}

class mainQBDialogFrame extends Frame
{

	// Fairly standard...nothing exciting here...

	String login;	// login name

	mainQBDialogFrame ( String title, String ID )
	{
		super ( title );
		login = ID;
	}

	mainQBDialog mainInputDialog;
	public void show()
	{
		mainInputDialog = new mainQBDialog ( this, "MO Question Bank", login );
		mainInputDialog.show();
	}

	public boolean handleEvent ( Event evtObj, Object arg )
	{
		if ( evtObj.id == Event.WINDOW_DESTROY )
		{
			setVisible ( false );
			return true;
		}
		return super.handleEvent ( evtObj );
	}
}


// The main menu...

class mainQBDialog extends Dialog
{
	Button addQ;	// Add questions
	Button seeQ;	// See/Edit/Delete questions
	Button quit;

	String login;

	mainQBDialog ( Frame parent, String title, String ID )
	{
		super ( parent, title, true );
		login = ID;

		setLayout ( new FlowLayout() );
		setSize ( 460, 70 );

		addQ = new Button ( "Add Question" );

		// Modify => Edit or Delete...

		seeQ = new Button ( "See/Modify Existing Questions" );
		quit = new Button ( "Quit" );

		add ( addQ );
		add ( seeQ );
		add ( quit );
	}

	public boolean handleEvent ( Event evtObj )
	{
		if ( evtObj.id == Event.WINDOW_DESTROY )
		{
			dispose();
			return true;
		}
		return super.handleEvent ( evtObj );
	}

	public boolean action ( Event evtObj, Object arg )
	{
		if ( evtObj.target instanceof Button )
		{
			if ( arg.equals ( "Add Question" ) )
			{
				// Set up input frame...
				addQuestionQBDialogFrame inputFrame;

				inputFrame = new addQuestionQBDialogFrame ( "MO Question Bank", login );
				inputFrame.show();
				inputFrame.setSize ( 500, 350 );

				return true;
			}
				
			if ( arg.equals ( "See/Modify Existing Questions" ) )
			{
				// Set up input frame...
				seeQuestionQBDialogFrame inputFrame;

				inputFrame = new seeQuestionQBDialogFrame ( "MO Question Bank", login );
				inputFrame.show();
				inputFrame.setSize ( 500, 300 );

				return true;
			}

			if ( arg.equals ( "Quit" ) )
			{
				dispose();
				return true;
			}
		}
		return false;
	}
}

class addQuestionQBDialogFrame extends Frame
{
	String login;	// login name

	// Again, nothing much here...

	addQuestionQBDialogFrame ( String title, String ID )
	{
		super ( title );
		login = ID;
	}

	addQuestionQBDialog addQuestionInputDialog;

	public void show()
	{
		addQuestionInputDialog = new addQuestionQBDialog ( this, "MO Question Bank", login );
		addQuestionInputDialog.show();
	}

	public boolean handleEvent ( Event evtObj, Object arg )
	{
		if ( evtObj.id == Event.WINDOW_DESTROY )
		{
			setVisible ( false );
			return true;
		}
		return super.handleEvent ( evtObj );
	}
}


// Add question...

class addQuestionQBDialog extends Dialog
{
	String login;	// login name

	List q_category;
	Scrollbar diff_level;
	Label diff_level_num;	// The diff. level selected
	TextArea question;	// The question text
	TextField choiceA, choiceB, choiceC, choiceD;	// Choices...
	CheckboxGroup answer;	// The correct answer... A, B, C or D
	Checkbox ans_a, ans_b, ans_c, ans_d;
	Button done;

	//declare jdbc variables
	// The driver to load
	static final String driver = "oracle.jdbc.driver.OracleDriver";

	// The connect string 
	static final String connect_string = 
                  "jdbc:oracle:thin:satyam/satyam@everest:1521:GEN";

	// The connection to the database
	Connection conn;

	addQuestionQBDialog ( Frame parent, String title, String ID )
	{
		super ( parent, title, true );

		login = ID;

		setLayout ( new FlowLayout() );
		setSize ( 460, 300 );

		q_category = new List ( 3, false );	// false => single-select,
											// 3 => 3 items visible at
											// a time.

		// Read the list of question categories from DBase...
		//this try-catch block is important as forName and getConnection
		//throw certain exceptions
		try
		{
			//first call initialiser functions	
			Class.forName (driver);

			//connect to the database
			conn = DriverManager.getConnection (connect_string);

			// Create a statement
			Statement stmt = conn.createStatement ();
			//jdbc initialisation done
			ResultSet rset = stmt.executeQuery ("select category from QCategory");

			// Fill up the category list...
			while( rset.next() )
				q_category.addItem(rset.getString(1));
		}
		catch(Exception e)
		{
			myError error;
			error = new myError ( e.getMessage(), 80, 80 );
			error.show();
			error.resize ( 100, 100 );
		}

		q_category.select ( 0 );	// select 1st item in list.
		add ( new Label ( "Select question category" ) );
		add ( q_category );

		// Blank question to begin with, 10 lines visible, 30 char.
		// per line...
		question = new TextArea ( "", 10, 30 );
		question.setEditable ( true );	// must be editable
	
		add ( new Label ( "Enter the question" ) );
		add ( question );

		// The choices...
		add ( new Label ( "Choice A" ) );
		choiceA = new TextField ( 50 ); 
		add ( choiceA );
		add ( new Label ( "Choice B" ) );
		choiceB = new TextField ( 50 );
		add ( choiceB );
		add ( new Label ( "Choice C" ) );
		choiceC = new TextField ( 50 );
		add ( choiceC );
		add ( new Label ( "Choice D" ) );
		choiceD = new TextField ( 50 );
		add ( choiceD );

		add ( new Label ( "Correct answer" ) );
		answer = new CheckboxGroup();

		ans_a = new Checkbox ( "A", answer, true );
		ans_b = new Checkbox ( "B", answer, false );
		ans_c = new Checkbox ( "C", answer, false );
		ans_d = new Checkbox ( "D", answer, false );

		add ( ans_a ); add ( ans_b ); add ( ans_c ); add ( ans_d );
		
		add ( new Label ( "Select difficulty level" ) );
		diff_level_num = new Label("1");
		add ( diff_level_num );
		diff_level = new Scrollbar ( Scrollbar.HORIZONTAL, 1, 1, 1, 11 ); 
		add ( diff_level );

		done = new Button ( "Done" );
		add ( done );
	}

	public boolean handleEvent ( Event evtObj )
	{
		if ( evtObj.id == Event.WINDOW_DESTROY )
		{
			dispose();
			return true;
		}
		return super.handleEvent ( evtObj );
	}

	public boolean action ( Event evtObj, Object arg )
	{
		if ( evtObj.target instanceof Button )
		{
			if ( arg.equals ( "Done" ) )
			{
				// Output info to DBase.
				try
				{
					//first call initialiser functions	
					Class.forName (driver);

					//connect to the database
					conn = DriverManager.getConnection (connect_string);

					//get the next question no from database
					Statement qno_stmt = conn.createStatement ();
					ResultSet q = qno_stmt.executeQuery ("select (max(qno) + 1) from question");
					q.next();
					int QNo=q.getInt(1);


					// Statement to fill table entry...
					PreparedStatement insert_stmt = conn.prepareStatement (
"insert into question (qno,q_category,q_difficulty_level,question,a,b,c,d,prof_id,answer) values (?,?,?,?,?,?,?,?,?,?)");
					insert_stmt.setInt(1, QNo);
					insert_stmt.setString(2,q_category.getSelectedItem());
					insert_stmt.setInt(3,diff_level.getValue());
					insert_stmt.setString(4,question.getText());
					insert_stmt.setString(5,choiceA.getText());
					insert_stmt.setString(6,choiceB.getText());
					insert_stmt.setString(7,choiceC.getText());
					insert_stmt.setString(8,choiceD.getText());
					insert_stmt.setString(9,login);
					insert_stmt.setString(10,String.valueOf ( answer.getCurrent().getLabel().charAt(0) ) );
					//after insert no of questions for the prof should ++
					insert_stmt.executeUpdate();
				}
				catch(Exception e)
				{
					myError error;
					error = new myError ( e.getMessage(), 80, 80 );
					error.show();
					error.resize ( 100, 100 );
				}

				dispose();
				return true;
			}
		}
		else if ( evtObj.target instanceof Scrollbar )
		{
			diff_level_num.setText ( Integer.toString (
			diff_level.getValue() ) );

			return true;
		}
		return false;
	}
}

// Frame for dialog box
class seeQuestionQBDialogFrame extends Frame
{
	seeQuestionQBDialog seeQuestionInputDialog;
	String login;

	seeQuestionQBDialogFrame ( String title, String ID )
	{
		super ( title );
		login = ID;
	}

	public void show()
	{
		seeQuestionInputDialog = new seeQuestionQBDialog ( this, "MO Question Bank", login );
		seeQuestionInputDialog.show();
	}

	public boolean handleEvent ( Event evtObj, Object arg )
	{
		if ( evtObj.id == Event.WINDOW_DESTROY )
		{
			setVisible ( false );
			return true;
		}
		return super.handleEvent ( evtObj );
	}
}

// View/Edit/Modify questions...
class seeQuestionQBDialog extends Dialog
{
	List q_category;
	Button done;
	TextArea question;
	Label diff_level_label;
	String choiceA, choiceB, choiceC, choiceD;	// The actual text
	Label labelA, labelB, labelC, labelD;		// The labels
	TextField correctAnswer;

	Button prev;
	Button edit;
	Button delete;
	Button next;
	Button quit;

	boolean edited; // Need to keep track of "edited" status of
					// current question.

	String login;

	//declare jdbc variables
	// The driver to load
	static final String driver = "oracle.jdbc.driver.OracleDriver";

	// The connect string 
	static final String connect_string = 
                  "jdbc:oracle:thin:satyam/satyam@everest:1521:GEN";

	// The connection to the database
	Connection conn;

	seeQuestionQBDialog ( Frame parent, String title, String ID )
	{
		super ( parent, title, true );
		edited = false;
		login = ID; 

		setLayout ( new FlowLayout() );
		setSize ( 460, 300 );

		q_category = new List ( 3, false );
	
		// Read the list of question categories from DBase...
		//this try-catch block is important as forName and getConnection
		//throw certain exceptions
		try
		{
			//first call initialiser functions	
			Class.forName (driver);

			//connect to the database
			conn = DriverManager.getConnection (connect_string);

			// Create a statement
			Statement stmt = conn.createStatement ();
			//jdbc initialisation done
			ResultSet rset = stmt.executeQuery ("select category from QCategory where category!='other'");

			// Fill the category list...
			while( rset.next() )
				q_category.addItem(rset.getString(1));
		}
		catch(Exception e)
		{
			myError error;
			error = new myError ( e.getMessage(), 80, 80 );
			error.show();
			error.resize ( 100, 100 );
		}

		q_category.select ( 0 );

		add ( new Label ( "Select question category" ) );
		add ( q_category );

		done = new Button ( "Done" );
		add ( done );

		question = new TextArea ( "", 10, 30 );
		question.setEditable ( false );
		add ( question );

		add ( new Label ( "Difficulty level: " ) );
		diff_level_label = new Label(); add ( diff_level_label );

		add ( new Label ( "A" ) );
		labelA = new Label ( choiceA ); add ( labelA );
		add ( new Label ( "B" ) );
		labelB = new Label ( choiceB ); add ( labelB );
		add ( new Label ( "C" ) );
		labelC = new Label ( choiceC ); add ( labelC );
		add ( new Label ( "D" ) );
		labelD = new Label ( choiceD ); add ( labelD );

		correctAnswer = new TextField ( 1 );
		add ( correctAnswer );
		correctAnswer.setEditable ( false );

		prev = new Button ( "<<Prev" );
		edit = new Button ( "Edit" );
		next = new Button ( "Next>>" );
		quit = new Button ( "Quit" );
		delete = new Button ( "DELETE" );

		add ( prev );
		add ( edit );
		add ( next );
		add ( delete );
		add ( quit );
	}

	public boolean handleEvent ( Event evtObj )
	{
		if ( evtObj.id == Event.WINDOW_DESTROY )
		{
			dispose();
			return true;
		}
		return super.handleEvent ( evtObj );
	}

			//we allocate some memory here and change it later 
			//this is important, o.w you get compiler error
			int qnoArray[]=new int[2];
			int q_diff_levelArray[]=new int[2];
			String questionArray[]=new String[2];
			String choiceArrayA[]=new String[2];
			String choiceArrayB[]=new String[2];
			String choiceArrayC[]=new String[2];
			String choiceArrayD[]=new String[2];
			String prof_idArray[]=new String[2];
			String answerArray[]=new String[2];

			//no of questions that the query returns
			int size=0;
			//current question being displayed
			int curr=0;

	public boolean action ( Event evtObj, Object arg )
	{
		if ( evtObj.target instanceof Button )
		{
			if ( arg.equals ( "Done" ) )	// ...selected category...
			{
				try
				{
					//first call initialiser functions	
					Class.forName (driver);

					//connect to the database
					conn = DriverManager.getConnection (connect_string);
	
					// Create a statement
					PreparedStatement question_stmt = 
					conn.prepareStatement 
					("Select q_difficulty_level,question, a, b, c, d,prof_id, answer, qno from question where q_category=?");
					PreparedStatement count_stmt =
					conn.prepareStatement ("Select count(question) from question where q_category=?");
					question_stmt.setString(1,q_category.getSelectedItem());
					count_stmt.setString(1,q_category.getSelectedItem());
					ResultSet questions=question_stmt.executeQuery();
					ResultSet count=count_stmt.executeQuery();

					count.next();
					size=count.getInt(1);	// Total # of questions of
											// this category

					// Allocate space for them, the choices, the
					// answers, diff. levels and creators' logins.

					qnoArray=new int[size];
					q_diff_levelArray=new int[size];
					questionArray=new String[size];
					choiceArrayA=new String[size];
					choiceArrayB=new String[size];
					choiceArrayC=new String[size];
					choiceArrayD=new String[size];
					prof_idArray=new String[size];
					answerArray=new String[size];

					// Fill it...
					int i=0;
					while(questions.next())
					{
						q_diff_levelArray[i]=questions.getInt(1);
						questionArray[i]=questions.getString(2);
						choiceArrayA[i]=questions.getString(3);
						choiceArrayB[i]=questions.getString(4);
						choiceArrayC[i]=questions.getString(5);
						choiceArrayD[i]=questions.getString(6);
						prof_idArray[i]=questions.getString(7);
						answerArray[i]=questions.getString(8);
						qnoArray[i]=questions.getInt(9);
						i++;
					}

					// Set up details of first question...
					if(size!=0)
					{
						diff_level_label.setText ( Integer.toString ( q_diff_levelArray[0], 10 ) );
						question.setText ( questionArray[0] );
						labelA.setText ( choiceArrayA[0] );
						labelB.setText ( choiceArrayB[0] );
						labelC.setText ( choiceArrayC[0] );
						labelD.setText ( choiceArrayD[0] );
						correctAnswer.setText ( answerArray[0] );
					}
				}
				catch(Exception e)
				{
					myError error;
					error = new myError ( e.getMessage(), 100, 100 );
					error.show();
					error.resize ( 400, 400 );
				}
			return true;
			}

			if ( arg.equals ( "<<Prev" ) )
			{
				if ( edited )	// ...save the curr. question before
								// moving on
				{
					edited = false;
					question.setEditable ( false );
					correctAnswer.setEditable ( false );
				
					// Capture changes...
					questionArray[curr]=question.getText();
					answerArray[curr]=correctAnswer.getText();

				//	write_question_details_to_DBase
				//  corresponding to curr;

				// Output info to DBase.
					try
					{
					//first call initialiser functions	
					Class.forName (driver);

					//connect to the database
					conn = DriverManager.getConnection (connect_string);

				// Create a statement
				PreparedStatement update_stmt = conn.prepareStatement (
"update question set question=?, answer=? where qno=?");
				update_stmt.setString(1,question.getText());	//correct
				update_stmt.setString(2,correctAnswer.getText());
				update_stmt.setInt(3, qnoArray[curr]);
				update_stmt.executeUpdate();
				}
				catch(Exception e)
				{
					myError error;
					error = new myError ( e.getMessage(), 80, 80 );
					error.show();
					error.resize ( 100, 100 );
				}

				}

				if(curr>0)	// Can you go back?
				{
					curr--; // go back...

					// get details of prev. question...
					diff_level_label.setText ( Integer.toString ( q_diff_levelArray[curr], 10 ) );
					question.setText ( questionArray[curr] );
					labelA.setText ( choiceArrayA[curr] );
					labelB.setText ( choiceArrayB[curr] );
					labelC.setText ( choiceArrayC[curr] );
					labelD.setText ( choiceArrayD[curr] );
					correctAnswer.setText ( answerArray[curr] );
				}
				return true;
			}

			if ( arg.equals ( "Edit" ) )
			{
				if ( size == 0 )
					return true;	// Nothing to edit

				// Is this user the creator of the question - he's the
				// only one who can edit...
				if ( prof_idArray[curr].equals ( login ) )
				{
					edited = true;	// Remember that its been changed...

					// Allow changes...
					question.setEditable ( true );
					correctAnswer.setEditable ( true );
				}
				else
				{
					myError error;

					error = new myError ( "Please report errors/suggestions to " + prof_idArray [ curr ], 50, 50 );
					error.show();
					error.resize ( 300, 200 );
				}
				return true;
			}

			// Similar to Prev...
			if ( arg.equals ( "Next>>" ) )
			{
				if ( edited )
				{
					edited = false;
					question.setEditable ( false );
					correctAnswer.setEditable ( false );

					questionArray[curr]=question.getText();
					answerArray[curr]=correctAnswer.getText();
					
				//	write_question_details_to_DBase();
					//  corresponding to curr;

				// Output info to DBase.
					try
					{
					//first call initialiser functions	
					Class.forName (driver);

					//connect to the database
					conn = DriverManager.getConnection (connect_string);

				// Create a statement
				PreparedStatement update_stmt = conn.prepareStatement (
"update question set question=?, answer=? where qno=?");
				update_stmt.setString(1,question.getText());	//correct
				update_stmt.setString(2,correctAnswer.getText());
				update_stmt.setInt(3, qnoArray[curr]);
				update_stmt.executeUpdate();
				}
				catch(Exception e)
				{
					myError error;
					error = new myError ( e.getMessage(), 80, 80 );
					error.show();
					error.resize ( 100, 100 );
				}


				}

				if(curr<size-1)
				{
					curr++;
					diff_level_label.setText ( Integer.toString ( q_diff_levelArray[curr], 10 ) );
					question.setText ( questionArray[curr] );
					labelA.setText ( choiceArrayA[curr] );
					labelB.setText ( choiceArrayB[curr] );
					labelC.setText ( choiceArrayC[curr] );
					labelD.setText ( choiceArrayD[curr] );
					correctAnswer.setText ( answerArray[curr] );
				}
				return true;
			}

			if ( arg.equals ( "Quit" ) )
			{
				if ( edited )	// ...then output changes...
				{
					edited = false;
				//	write_question_details_to_DBase();
					//  corresponding to curr;

				// Output info to DBase.
					try
					{
					//first call initialiser functions	
					Class.forName (driver);

					//connect to the database
					conn = DriverManager.getConnection (connect_string);

				// Create a statement
				PreparedStatement update_stmt = conn.prepareStatement (
"update question set question=?, answer=? where qno=?");
				update_stmt.setString(1,question.getText());	//correct
				update_stmt.setString(2,correctAnswer.getText());
				update_stmt.setInt(3, qnoArray[curr]);
				update_stmt.executeUpdate();
				}
				catch(Exception e)
				{
					myError error;
					error = new myError ( e.getMessage(), 80, 80 );
					error.show();
					error.resize ( 100, 100 );
				}


				}

				dispose();
				return true;
			}

			// Similar to Edit...
			if ( arg.equals ( "DELETE" ) )
			{
				if ( size == 0 )
					return true;
				if ( prof_idArray[curr].equals ( login ) )
				{
				try
				{
					//first call initialiser functions	
					Class.forName (driver);

					//connect to the database
					conn = DriverManager.getConnection (connect_string);

				// Create a statement
				PreparedStatement delete_stmt = conn.prepareStatement (
"delete question where qno=?");
				delete_stmt.setInt(1, qnoArray[curr]);
				delete_stmt.executeUpdate();
				}
				catch(Exception e)
				{
					myError error;
					error = new myError ( e.getMessage(), 80, 80 );
					error.show();
					error.resize ( 300, 200 );
				}

				//	delete the question in the arrays
				for(int i=curr;i<size-1;i++)
				{
					qnoArray[i]=qnoArray[i+1];
					q_diff_levelArray[i]=q_diff_levelArray[i+1];
					questionArray[i]=questionArray[i+1];
					choiceArrayA[i]=choiceArrayA[i+1];
					choiceArrayB[i]=choiceArrayB[i+1];
					choiceArrayC[i]=choiceArrayC[i+1];
					choiceArrayD[i]=choiceArrayD[i+1];
					prof_idArray[i]=prof_idArray[i+1];
					answerArray[i]=answerArray[i+1];
				}
				size--;
					
				//display the NEW current record
				diff_level_label.setText ( Integer.toString ( q_diff_levelArray[curr], 10 ) );
				question.setText ( questionArray[curr] );
				labelA.setText ( choiceArrayA[curr] );
				labelB.setText ( choiceArrayB[curr] );
				labelC.setText ( choiceArrayC[curr] );
				labelD.setText ( choiceArrayD[curr] );
				correctAnswer.setText ( answerArray[curr] );

				//	delete the question from the DBase
				}
				else
				{
					myError error;

					error = new myError ( "Sorry, you cannot delete this question" , 80, 80 );
					error.show();
					error.resize ( 300, 200 );
				}
				return true;
			}
		}
		return false;
	}
}

// A simple error message displaying class...

class myError extends Frame
{
	String errorMessage;
	int x_err, y_err;

	myError ( String errMsg, int x, int y )
	{
		super ( "Error!" );
		errorMessage = errMsg;
		x_err = x;
		y_err = y;
	}

	public boolean handleEvent ( Event evtObj )
	{
		if ( evtObj.id == Event.WINDOW_DESTROY )
		{
			hide();
			return true;
		}
		return super.handleEvent ( evtObj );
	}

	public void paint ( Graphics g )
	{
		g.drawString ( errorMessage, x_err, y_err );
	}
}
